@@ -653,6 +653,16 @@ class GitRepository(object):
 
         return out[0].decode().strip()
 
+    @staticmethod
+    def ensure_refs_heads(branch):
+        """
+        Make sure a branch name is prefixed with `refs/heads'
+        """
+        if (branch.startswith('refs/heads/')):
+            return branch
+        #return f'refs/heads/{branch}'
+        return f'{branch}'
+
 #{ Tags
 
     def create_tag(self, name, msg=None, commit=None, sign=False, keyid=None):
@@ -1102,6 +1112,8 @@ class GitRepository(object):
                 filename = parts.pop()
                 if sizes:
                     mode, type, sha1, size = (part.decode() for part in parts)
+                    # Git submodules report '-' instead of a size
+                    size = size if size != '-' else 0
                     yield mode, type, sha1, int(size), filename
                 else:
                     mode, type, sha1 = (part.decode() for part in parts)
@@ -1666,6 +1678,7 @@ class GitRepository(object):
         @type since: C{str}
         """
         args = GitArgs('--pretty=format:%H')
+        args.add("--no-show-signature")
         args.add_false(merges, '--no-merges')
         args.add('--grep=%s' % regex)
         args.add_true(since, since)
@@ -1981,8 +1994,9 @@ class GitRepository(object):
             # A submodules is shown as "commit" object in ls-tree:
             if objtype == "commit":
                 nextpath = os.path.join(path, name)
-                submodules.append((nextpath.replace(self.path, '').lstrip('/'),
-                                   commit))
+                if nextpath.startswith(self.path):
+                    nextpath = nextpath[len(self.path):].lstrip('/')
+                submodules.append((nextpath, commit))
                 if recursive:
                     submodules += self.get_submodules(commit, path=nextpath,
                                                       recursive=recursive)
