@@ -33,7 +33,7 @@ from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
 from gbp.deb.source import DebianSource, DebianSourceError, FileVfs
 from gbp.deb.format import DebianSourceFormat
 from gbp.git.vfs import GitVfs
-from gbp.deb.upstreamsource import DebianUpstreamSource, unpack_component_tarball
+from gbp.deb.upstreamsource import DebianUpstreamSource, DebianAdditionalTarball
 from gbp.errors import GbpError
 import gbp.log
 import gbp.notifications
@@ -139,10 +139,13 @@ def overlay_extract_origs(source, tarball_dir, dest_dir, options):
 
     # Unpack additional tarballs
     for c in options.components:
-        tarball = os.path.join(tarball_dir, source.upstream_tarball_name(
-            comp_type, component=c))
-        gbp.log.info("Extracting '%s' to '%s/%s'" % (os.path.basename(tarball), dest_dir, c))
-        unpack_component_tarball(dest_dir, c, tarball, [])
+        tarball = DebianAdditionalTarball(os.path.join(tarball_dir,
+                                                       source.upstream_tarball_name(
+                                                           comp_type, component=c)),
+                                          component=c)
+        gbp.log.info("Extracting '%s' to '%s/%s'" % (os.path.basename(tarball.path),
+                                                     dest_dir, c))
+        tarball.unpack(dest_dir, [])
 
 
 def source_vfs(repo, options, tree):
@@ -209,7 +212,7 @@ def get_pbuilder_dist(options, repo, native=False):
         if len(parts) == 2:  # e.g. debian/stretch
             suite = parts[1]
             if vendor == parts[0]:
-                dist = '' if suite in ['sid', 'master'] else suite
+                dist = '' if suite in ['sid', 'master', 'main', 'latest'] else suite
             else:
                 dist = '%s_%s' % (parts[0], suite)
         # Branches in Debian often omit the debian/ prefix
@@ -284,18 +287,20 @@ def disable_hooks(options):
             setattr(options, hook, '')
 
 
-def changes_file_suffix(builder, dpkg_args):
+def changes_file_suffix(builder, dpkg_args, arch):
     """
-    >>> changes_file_suffix('debuild', ['-A'])
+    >>> changes_file_suffix('debuild', ['-A'], '')
     'all'
-    >>> changes_file_suffix('debuild', ['-S'])
+    >>> changes_file_suffix('debuild', ['-S'], '')
     'source'
-    >>> changes_file_suffix('debuild -A', ['-uc', '-us'])
+    >>> changes_file_suffix('debuild -A', ['-uc', '-us'], '')
     'all'
-    >>> changes_file_suffix('debuild -S', ['-uc', '-us'])
+    >>> changes_file_suffix('debuild -S', ['-uc', '-us'], '')
     'source'
-    >>> changes_file_suffix('debuild', []) == du.get_arch()
+    >>> changes_file_suffix('debuild', [], '') == du.get_arch()
     True
+    >>> changes_file_suffix('debuild', [], 'arm64')
+    'arm64'
     """
     args = shlex.split(builder) + dpkg_args
     if '-S' in args:
@@ -303,15 +308,15 @@ def changes_file_suffix(builder, dpkg_args):
     elif '-A' in args:
         return 'all'
     else:
-        return os.getenv('ARCH', None) or du.get_arch()
+        return arch or os.getenv('ARCH', None) or du.get_arch()
 
 
-def changes_file_name(source, build_dir, builder, dpkg_args):
+def changes_file_name(source, build_dir, builder, dpkg_args, arch):
     return os.path.abspath("%s/../%s_%s_%s.changes" %
                            (build_dir,
                             source.changelog.name,
                             source.changelog.noepoch,
-                            changes_file_suffix(builder, dpkg_args)))
+                            changes_file_suffix(builder, dpkg_args, arch)))
 
 
 def check_branch(repo, options):
@@ -323,15 +328,16 @@ def check_branch(repo, options):
     branch = None
     try:
         branch = repo.get_branch()
-    except GitRepositoryError:
+    except GitRepositoryError as repo_error:
         # Not being on any branch is o.k. with --git-ignore-branch
         if not options.ignore_branch:
-            raise
+            gbp.log.err(repo_error)
+            raise GitRepositoryError("Use --git-ignore-branch to ignore")
 
     ignore = options.ignore_new or options.ignore_branch
     if branch != options.debian_branch and not ignore:
-            gbp.log.err("You are not on branch '%s' but on '%s'" % (options.debian_branch, branch))
-            raise GbpError("Use --git-ignore-branch to ignore or --git-debian-branch to set the branch name.")
+        gbp.log.err("You are not on branch '%s' but on '%s'" % (options.debian_branch, branch))
+        raise GbpError("Use --git-ignore-branch to ignore or --git-debian-branch to set the branch name.")
     return branch
 
 
@@ -392,6 +398,8 @@ def build_parser(name, prefix=None):
                                       help="Compression type, default is '%(compression)s'")
     orig_group.add_config_file_option(option_name="compression-level", dest="comp_level",
                                       help="Compression level, default is '%(compression-level)s'")
+    orig_group.add_config_file_option(option_name="upstream-signatures", dest="upstream_signatures",
+                                      help="use upstream signatures, default is auto", type='tristate')
     orig_group.add_config_file_option("component", action="append", metavar='COMPONENT',
                                       dest="components")
     branch_group.add_config_file_option(option_name="upstream-branch", dest="upstream_branch")
@@ -509,7 +517,8 @@ def main(argv):
                      else source.upstream_version)
             export_dir = os.path.join(output_dir, "%s-%s" % (source.sourcepkg, major))
             build_dir = export_dir if options.export_dir else repo.path
-            changes_file = changes_file_name(source, build_dir, options.builder, dpkg_args)
+            changes_file = changes_file_name(source, build_dir, options.builder, dpkg_args,
+                                             options.pbuilder_arch)
 
             # Run preexport hook
             if options.export_dir and options.preexport:
