@@ -19,6 +19,7 @@
 
 import os.path
 import re
+import typing
 import sys
 import shutil
 import gbp.command_wrappers as gbpc
@@ -33,7 +34,7 @@ from gbp.deb.changelog import ChangeLog, NoChangeLogError
 from gbp.scripts.common import ExitCodes, maybe_debug_raise
 from gbp.scripts.common.hook import Hook
 
-user_customizations = {}
+user_customizations: typing.Dict[str, str] = {}
 snapshot_re = re.compile(r'\s*\*\* SNAPSHOT build @(?P<commit>[a-z0-9]+)\s+\*\*')
 
 
@@ -49,6 +50,9 @@ def guess_version_from_upstream(repo, upstream_tag_format, upstream_branch, cp=N
                                                     upstream_branch,
                                                     epoch=epoch,
                                                     debian_release=False)
+        if version is None:
+            gbp.log.warn("Failed to find upstream version tag")
+            return None
         gbp.log.debug("Found upstream version %s." % version)
         if compare_versions(version, cmp_version) > 0:
             return "%s-1" % version
