@@ -26,14 +26,15 @@ import pipes
 import time
 import gbp.command_wrappers as gbpc
 from gbp.deb.dscfile import DscFile
-from gbp.deb.upstreamsource import DebianUpstreamSource, unpack_component_tarball
+from gbp.deb.upstreamsource import (DebianUpstreamSource,
+                                    DebianAdditionalTarball)
 from gbp.deb.git import (DebianGitRepository, GitRepositoryError)
 from gbp.deb.changelog import ChangeLog
 from gbp.git import rfc822_date_to_git
 from gbp.git.modifier import GitModifier
 from gbp.git.vfs import GitVfs
 from gbp.config import (GbpOptionParserDebian, GbpOptionGroup,
-                        no_upstream_branch_msg)
+                        no_debian_branch_msg, no_upstream_branch_msg)
 from gbp.errors import GbpError
 from gbp.scripts.common import ExitCodes, debug_exc
 from gbp.scripts.common import repo_setup
@@ -197,14 +198,14 @@ def apply_debian_patch(repo, source, dsc, upstream_commit, options):
         os.chdir(repo.path)
 
 
-def create_missing_branch(repo, branch, options):
+def create_missing_branch(repo, branch, options, err_msg):
     if not repo.has_branch(branch):
         if options.create_missing_branches:
             gbp.log.info("Creating missing branch '%s'" % branch)
             repo.create_branch(branch)
         else:
-            raise GbpError(no_upstream_branch_msg % branch +
-                           "\nAlso check the --create-missing-branches option.")
+            raise GbpError(err_msg + "\n"
+                           "Also check the --create-missing-branches option.")
 
 
 def import_native(repo, source, dsc, options):
@@ -216,7 +217,8 @@ def import_native(repo, source, dsc, options):
         branch = None
     else:
         branch = options.debian_branch
-        create_missing_branch(repo, branch, options)
+        create_missing_branch(repo, branch, options,
+                              no_debian_branch_msg % branch)
 
     author = get_author_from_changelog(source.unpacked)
     committer = get_committer_from_author(author, options)
@@ -247,14 +249,18 @@ def import_upstream(repo, source, dsc, options):
         branch = None
     else:
         branch = options.upstream_branch
-        create_missing_branch(repo, branch, options)
+        create_missing_branch(repo, branch, options,
+                              no_upstream_branch_msg % branch)
 
     author = committer = {}
     commit_msg = "Import %s" % msg
 
+    upstream_parent = repo.vcs_tag_parent(options.vcs_tag,
+                                          dsc.upstream_version)
     commit = repo.commit_dir(source.unpacked,
                              commit_msg,
                              branch,
+                             other_parents=upstream_parent,
                              author=author,
                              committer=committer)
 
@@ -335,6 +341,7 @@ def build_parser(name):
                                         dest="upstream_branch")
     branch_group.add_boolean_config_file_option(option_name="create-missing-branches",
                                                 dest="create_missing_branches")
+    branch_group.add_config_file_option(option_name="upstream-vcs-tag", dest="vcs_tag")
 
     tag_group.add_boolean_config_file_option(option_name="sign-tags",
                                              dest="sign_tags")
@@ -483,11 +490,17 @@ def main(argv):
 
         # unpack
         dirs['tmp'] = os.path.abspath(tempfile.mkdtemp(dir='..'))
-        source = DebianUpstreamSource(dsc.tgz)
-        source.unpack(dirs['tmp'], options.filters)
-        for (component, tarball) in dsc.additional_tarballs.items():
-            gbp.log.info("Found component tarball '%s'" % os.path.basename(tarball))
-            unpack_component_tarball(source.unpacked, component, tarball, options.filters)
+        sigfile = '{}.asc'.format(dsc.tgz)
+        sigfile = sigfile if sigfile in dsc.sigs else None
+        sources = [DebianUpstreamSource(dsc.tgz, sig=sigfile)]
+        for component, tarball in dsc.additional_tarballs.items():
+            sigfile = '{}.asc'.format(tarball)
+            sigfile = sigfile if sigfile in dsc.sigs else None
+            sources.append(DebianAdditionalTarball(tarball, component))
+        sources[0].unpack(dirs['tmp'], options.filters)
+        for tarball in sources[1:]:
+            gbp.log.info("Found component tarball '%s'" % os.path.basename(tarball.path))
+            tarball.unpack(sources[0].unpacked, options.filters)
 
         if repo.find_version(options.debian_tag, dsc.version):
             gbp.log.warn("Version %s already imported." % dsc.version)
@@ -499,12 +512,12 @@ def main(argv):
 
         # import
         if dsc.native:
-            import_native(repo, source, dsc, options)
+            import_native(repo, sources[0], dsc, options)
         else:
             imported = False
             commit = repo.find_version(options.upstream_tag, dsc.upstream_version)
             if not repo.find_version(options.upstream_tag, dsc.upstream_version):
-                commit = import_upstream(repo, source, dsc, options)
+                commit = import_upstream(repo, sources[0], dsc, options)
                 imported = True
 
             if not repo.has_branch(options.debian_branch):
@@ -515,15 +528,12 @@ def main(argv):
                                    options.debian_branch)
 
             if dsc.diff or dsc.deb_tgz:
-                apply_debian_patch(repo, source, dsc, commit, options)
+                apply_debian_patch(repo, sources[0], dsc, commit, options)
             else:
                 gbp.log.warn("Didn't find a diff to apply.")
 
             if imported and options.pristine_tar:
-                repo.create_pristine_tar_commits(commit,
-                                                 dsc.tgz,
-                                                 dsc.additional_tarballs.items())
-
+                repo.create_pristine_tar_commits(commit, sources)
         if repo.get_branch() == options.debian_branch or repo.empty:
             # Update HEAD if we modified the checked out branch
             repo.force_head(options.debian_branch, hard=True)
