@@ -21,10 +21,13 @@ class MockGitRepository:
     def has_pristine_tar_branch(self):
         return self.with_branch
 
+    def has_branch(self, branch, remote=False):
+        return branch == 'pristine-tar' and self.with_branch
+
     def pristine_tar_branch(self):
         'pristine-tar'
 
-    def grep_log(self, regex, branch):
+    def grep_log(self, regex, branch, merges=True):
         return None
 
     def get_commit_info(self, commit):
@@ -136,3 +139,8 @@ class TestDetection(unittest.TestCase):
         guessed = export_orig.guess_comp_type(
             'gz', self.source, repo, None)
         self.assertEqual("gzip", guessed)
+
+    def test_guess_comp_type_no_repo(self):
+        guessed = export_orig.guess_comp_type(
+            'auto', self.source, None, str(self.tmpdir))
+        self.assertEqual('gzip', guessed)
