@@ -56,7 +56,8 @@ class RpmTestBase(object):
 
     def teardown(self):
         """Test case teardown"""
-        shutil.rmtree(self.tmpdir)
+        if not os.getenv("GBP_TESTS_NOCLEAN"):
+            shutil.rmtree(self.tmpdir)
 
 
 class TestSrcRpmFile(RpmTestBase):
@@ -231,7 +232,7 @@ class TestSpecFile(RpmTestBase):
         spec.protected('_delete_tag')('source', 0)
         eq_(spec.sources(), {})
         spec.protected('_delete_tag')('patch', 0)
-        spec.protected('_delete_tag')('patch', -1)
+        spec.protected('_delete_tag')('patch', 1)
         eq_(spec.protected('_patches')(), {})
         prev = spec.protected('_delete_tag')('invalidtag', None)
 
@@ -314,7 +315,7 @@ class TestSpecFile(RpmTestBase):
             for patch in spec.protected('_tags')['patch']['lines']:
                 patches[patch['num']] = patch['linevalue']
 
-            eq_(patches, {0: 'my_patch0', -1: 'my_patch'})
+            eq_(patches, {0: 'my_patch0', 1: 'my_patch'})
 
     def test_patch_series(self):
         """Test the getting the patches as a patchseries"""
@@ -334,6 +335,18 @@ class TestSpecFile(RpmTestBase):
         eq_(len(series), 2)
         eq_(os.path.basename(series[-1].path), '1.patch')
 
+    def test_patch_series_autosetup(self):
+        """Check patch series functionalitu with %autostup"""
+        spec_filepath = os.path.join(SPEC_DIR, 'gbp-test3.spec')
+        spec = SpecFileTester(spec_filepath)
+
+        eq_(len(spec.patchseries()), 2)
+        eq_(len(spec.patchseries(ignored=True)), 3)
+        spec.update_patches(['1.patch'], {})
+        eq_(len(spec.patchseries()), 1)
+        eq_(len(spec.patchseries(ignored=True)), 2)
+        eq_(spec.protected('_special_directives')['patch'], [])
+
     def test_patch_series_quirks(self):
         """Patches are applied in order different from the patch numbering"""
         spec_filepath = os.path.join(SPEC_DIR, 'gbp-test-quirks.spec')
